@@ -139,6 +139,7 @@ class ExasolConnectionManager(SQLConnectionManager):
     def get_credentials(cls, credentials):
         return credentials
 
+
     def add_query(self, sql, auto_begin=True, bindings=None,
                   abridge_sql_log=False):
         connection = self.get_thread_connection()
@@ -147,6 +148,11 @@ class ExasolConnectionManager(SQLConnectionManager):
         logger.debug(sql)
         logger.debug('Using {} connection "{}".'.format(self.TYPE, connection.name))
 
+        if sql.startswith('0CSV|'):
+            connection.handle.cursor().import_from_file(bindings, sql.split('|',1)[1])
+
+            return connection
+
         with self.exception_handler(sql):
             if abridge_sql_log:
                 logger.debug('On {}: {}....'.format(connection.name, sql[0:512]))
@@ -168,6 +174,13 @@ class ExasolCursor(object):
         self.connection = connection
         self.stmt = None
 
+    def import_from_file(self, agate_table, table):
+        self.connection.import_from_file(
+            agate_table.original_abspath, 
+            (table.split('.')[0], table.split('.')[1]),
+            import_params={'skip': 1})
+
+
     def execute(self, query):
         self.stmt = self.connection.execute(query)
         return self
